==> haskell-base-unicode-symbols-0.2.2.4-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-L8AjmazQitAEQ7hSQq5LiD
key: base-unicode-symbols-0.2.2.4-L8AjmazQitAEQ7hSQq5LiD
license: BSD3
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Monad.Unicode Data.Bool.Unicode Data.Eq.Unicode
    Data.Foldable.Unicode Data.Function.Unicode Data.List.Unicode
    Data.Monoid.Unicode Data.Ord.Unicode Prelude.Unicode
    Control.Category.Unicode
abi: 105a740235e4bac41ac78fba1475ec82
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/base-unicode-symbols-0.2.2.4
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-L8AjmazQitAEQ7hSQq5LiD
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.2.4-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-LJZ89aUbdoNKMBk8U5mv47
key: base-unicode-symbols-0.2.2.4-LJZ89aUbdoNKMBk8U5mv47
license: BSD3
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
author: Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Monad.Unicode Data.Bool.Unicode Data.Eq.Unicode
    Data.Foldable.Unicode Data.Function.Unicode Data.List.Unicode
    Data.Monoid.Unicode Data.Ord.Unicode Prelude.Unicode
    Control.Category.Unicode
abi: dc2bef393d05b8ef75ea10a48c9fb4e5
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/base-unicode-symbols-0.2.2.4
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-LJZ89aUbdoNKMBk8U5mv47
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
